============
Contributors
============

* Chris Stevens <chris.stevens@canterbury.ac.nz>
* Christopher Laing <christopher@laing.nz>

=================
Original creators
=================

* Georgios Doulis
* Joerg Frauendiener <joergf@maths.otago.ac.nz>
* Chris Stevens <chris.stevens@canterbury.ac.nz>
* Ben Whale